==> 0.10.1.tar.gz: lib/bloc/common_widgets/upi_details_dialog.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/text_styling.dart';

import '../../models/cash_coin_resppnse.dart';
import '../../utils/basicInfo.dart';
import '../cubits/cubit_main.dart';
import '../states/main_state.dart';

class UpiDetailsDialog extends StatefulWidget {

  final Function(dynamic data) nextCallBack;


  const UpiDetailsDialog({
    Key? key,

    required this.nextCallBack,

  }) : super(key: key);

  @override
  UpiDetailsDialogState createState() => UpiDetailsDialogState();
}

class UpiDetailsDialogState extends State<UpiDetailsDialog> {
  GlobalKey<FormState> formKey = GlobalKey();

  final cashController = TextEditingController();
  BasicInfo? basicInfo = BasicInfo();
  late TextStyleElements styleElements;
  late Widget upiTextField;

  @override
  initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    BasicInfo? basicInfo = BasicInfo();
    upiTextField = TextFormField(
      controller: cashController,
      cursorColor: HexColor(AppColors.appMainColor),
      onChanged: (upiid) {},

      style: styleElements
          .subtitle1ThemeScalable(context)
          .copyWith(color: HexColor(AppColors.appColorBlack65)),
      decoration: InputDecoration(
        fillColor: Colors.black12,
        filled: true,
        prefixIcon: const SizedBox(
          height: 25,
          width: 25,
          child: Image(
            image: AssetImage(
                'packages/loyalty_management_tool/assets/appimages/upi.png'),
          ),
        ),
        hintText: AppLocalizationsRewards.of(context)!.translate("upi_id"),
        hintStyle: styleElements
            .subtitle1ThemeScalable(context)
            .copyWith(color: HexColor(AppColors.appMainColor)),
        contentPadding: const EdgeInsets.all(16),
        border: UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
        labelText: AppLocalizationsRewards.of(context)!.translate("upi_id"),
      ),
    );

    return _getBody();
  }

  Widget _getBody() {
    return BlocBuilder<CubitMain, MainState>(builder: (context, state) {
      styleElements = TextStyleElements(context);
      return Padding(
        padding:const EdgeInsets.all(4),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Padding(
              padding: const EdgeInsets.only(
                  bottom: 30.0, left: 16, right: 16, top: 8),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                //Center Row contents horizontally,
                crossAxisAlignment: CrossAxisAlignment.start,
                //Center Row contents vertically,

                children: [
                  Expanded(
                    child: Align(
                      alignment: Alignment.center,
                      child: Container(
                        child: Text(
                          AppLocalizationsRewards.of(context)!
                              .translate("UPI_details"),
                          textAlign: TextAlign.center,
                          style: styleElements
                              .subtitle1ThemeScalable(context)
                              .copyWith(fontWeight: FontWeight.bold),
                        ),
                      ),
                    ),
                  ),
                  Align(
                    alignment: Alignment.centerRight,
                    child: InkWell(
                      onTap: () {

                        widget.nextCallBack("o");
                      },
                      child: Container(
                        child: Text(
                          AppLocalizationsRewards.of(context)!
                              .translate("next"),
                          textAlign: TextAlign.center,
                          style: styleElements
                              .subtitle1ThemeScalable(context)
                              .copyWith(
                                  fontWeight: FontWeight.bold,
                                  color: HexColor(AppColors.blueApp)),
                        ),
                      ),
                    ),
                  )
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(12),
              child: Text(
                AppLocalizationsRewards.of(context)!.translate("upi_des"),
                textAlign: TextAlign.center,
                style: styleElements.captionThemeScalable(context),
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(16),
              child: Text(
                AppLocalizationsRewards.of(context)!
                    .translate('amount_trans', arguments: {"amount": "1099"}),
                textAlign: TextAlign.center,
                style: styleElements
                    .subtitle1ThemeScalable(context)
                    .copyWith(fontWeight: FontWeight.bold),
              ),
            ),
            const SizedBox(
              width: 20,
            ),
            Padding(
                padding: const EdgeInsets.all(8.0), child: upiTextField),

            const SizedBox(
              width: 20,
            ),
            SizedBox(
              height: MediaQuery.of(context).viewInsets.bottom,
            )
          ],
        ),
      );
    });
  }

  dynamic getData(dynamic data) {
    return CashCoinInfo.fromJson(data);
  }

  String getBody(num amount) {
    return jsonEncode({
      "business_id": basicInfo!.businessId,
      "amount": amount,
      "service_charge_type": "widget.type",
      "country": "IN"
    });
  }
}

==> 0.11.1.tar.gz: lib/bloc/common_widgets/upi_details_dialog.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/text_styling.dart';

import '../../models/cash_coin_resppnse.dart';
import '../../utils/basicInfo.dart';
import '../cubits/cubit_main.dart';
import '../states/main_state.dart';

class UpiDetailsDialog extends StatefulWidget {
  final Function(dynamic data) nextCallBack;

  const UpiDetailsDialog({
    Key? key,
    required this.nextCallBack,
  }) : super(key: key);

  @override
  UpiDetailsDialogState createState() => UpiDetailsDialogState();
}

class UpiDetailsDialogState extends State<UpiDetailsDialog> {
  GlobalKey<FormState> formKey = GlobalKey();

  final cashController = TextEditingController();
  BasicInfo? basicInfo = BasicInfo();
  late TextStyleElements styleElements;
  late Widget upiTextField;

  @override
  initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    BasicInfo? basicInfo = BasicInfo();
    upiTextField = TextFormField(
      controller: cashController,
      cursorColor: HexColor(AppColors.appMainColor),
      onChanged: (upiid) {},
      style: styleElements
          .subtitle1ThemeScalable(context)
          .copyWith(color: HexColor(AppColors.appColorBlack65)),
      decoration: InputDecoration(
        fillColor: Colors.black12,
        filled: true,
        prefixIcon: const SizedBox(
          height: 25,
          width: 25,
          child: Image(
            image: AssetImage(
                'packages/loyalty_management_tool/assets/appimages/upi.png'),
          ),
        ),
        hintText: AppLocalizationsRewards.of(context)!.translate("upi_id"),
        hintStyle: styleElements
            .subtitle1ThemeScalable(context)
            .copyWith(color: HexColor(AppColors.appMainColor)),
        contentPadding: const EdgeInsets.all(16),
        border: UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
        labelText: AppLocalizationsRewards.of(context)!.translate("upi_id"),
      ),
    );

    return _getBody();
  }

  Widget _getBody() {
    return BlocBuilder<CubitMain, MainState>(builder: (context, state) {
      styleElements = TextStyleElements(context);
      return Padding(
        padding: const EdgeInsets.all(4),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Padding(
              padding: const EdgeInsets.only(
                  bottom: 30.0, left: 16, right: 16, top: 8),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                //Center Row contents horizontally,
                crossAxisAlignment: CrossAxisAlignment.start,
                //Center Row contents vertically,

                children: [
                  Expanded(
                    child: Align(
                      alignment: Alignment.center,
                      child: Container(
                        child: Text(
                          AppLocalizationsRewards.of(context)!
                              .translate("UPI_details"),
                          textAlign: TextAlign.center,
                          style: styleElements
                              .subtitle1ThemeScalable(context)
                              .copyWith(fontWeight: FontWeight.bold),
                        ),
                      ),
                    ),
                  ),
                  Align(
                    alignment: Alignment.centerRight,
                    child: InkWell(
                      onTap: () {
                        widget.nextCallBack("o");
                      },
                      child: Container(
                        child: Text(
                          AppLocalizationsRewards.of(context)!
                              .translate("next"),
                          textAlign: TextAlign.center,
                          style: styleElements
                              .subtitle1ThemeScalable(context)
                              .copyWith(
                                  fontWeight: FontWeight.bold,
                                  color: HexColor(AppColors.blueApp)),
                        ),
                      ),
                    ),
                  )
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(12),
              child: Text(
                AppLocalizationsRewards.of(context)!.translate("upi_des"),
                textAlign: TextAlign.center,
                style: styleElements.captionThemeScalable(context),
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(16),
              child: Text(
                AppLocalizationsRewards.of(context)!
                    .translate('amount_trans', arguments: {"amount": "1099"}),
                textAlign: TextAlign.center,
                style: styleElements
                    .subtitle1ThemeScalable(context)
                    .copyWith(fontWeight: FontWeight.bold),
              ),
            ),
            const SizedBox(
              width: 20,
            ),
            Padding(padding: const EdgeInsets.all(8.0), child: upiTextField),
            const SizedBox(
              width: 20,
            ),
            SizedBox(
              height: MediaQuery.of(context).viewInsets.bottom,
            )
          ],
        ),
      );
    });
  }

  dynamic getData(dynamic data) {
    return CashCoinInfo.fromJson(data);
  }

  String getBody(num amount) {
    return jsonEncode({
      "business_id": basicInfo!.businessId,
      "amount": amount,
      "service_charge_type": "widget.type",
      "country": "IN"
    });
  }
}
